.. _status:

==================
Status
==================

Supported features
------------------

qBittorrent v4.5.5 is supported.
The following table summarizes currently available APIs
and the corresponding attributes in :class:`~aioqbt.client.APIClient`.

.. list-table::
    :header-rows: 1

    * - API
      - Group
      - Note

    * - :APIWiki:`Authentication <#authentication>`
      - :class:`~.AuthAPI`
      -

    * - :APIWiki:`Application <#application>`
      - :class:`~.AppAPI`
      -

    * - :APIWiki:`Log <#log>`
      - :class:`~.LogAPI`
      -

    * - :APIWiki:`Sync <#sync>`
      - :class:`~.SyncAPI`
      -

    * - :APIWiki:`Transfer info <#transfer-info>`
      - :class:`~.TransferAPI`
      -

    * - :APIWiki:`Torrent management <#torrent-management>`
      - :class:`~.TorrentsAPI`
      -

    * - :APIWiki:`RSS <#rss-experimental>`
      - :class:`~.RSSAPI`
      - *experimental!*

    * - :APIWiki:`Search <#search>`
      - :class:`~.SearchAPI`
      - *experimental!*

Feature / pull requests and are welcome on `GitHub <https://github.com/tsangwpx/aioqbt>`_.
